Module api

Module api 

Esplora API

This module implements the types and deserializers needed to interact with an Esplora-compliant server.

Refer to the Esplora API specification for the complete API reference.

Modules

absolute
Provides type LockTime that implements the logic around nLockTime/OP_CHECKLOCKTIMEVERIFY.
block
Bitcoin blocks.
transaction
Bitcoin transactions.

Structs

Address
A Bitcoin address.
AddressStats
Statistics about an Address.
AddressTxsSummary
A summary of Transactions in which an Address is involved.
Amount
Amount
Block
Bitcoin block.
BlockHash
A bitcoin block hash.
BlockInfo
A summary of a Block.
BlockStatus
The status of a Block.
BlockSummaryDeprecated
Summary about a Block.
BlockTime
The UNIX timestamp and height of a Block.
CompactTarget
Encoding of 256-bit target as 32-bit float.
EsploraTx
A transaction in the format returned by Esplora.
FeeRate
Represents fee rate.
MempoolFeesSubmitPackage
The fees for a Transaction submitted as part of a package.
MempoolRecentTx
A Transaction that recently entered the mempool.
MempoolStats
Statistics about the mempool.
MerkleProof
A Merkle inclusion proof for a Transaction.
OutPoint
A reference to a transaction output.
OutputStatus
The status of a TxOut.
Script
Bitcoin script slice.
ScriptBuf
An owned, growable script.
ScriptHash
A hash of Bitcoin Script bytecode.
ScriptHashStats
Statistics about a scripthash’s confirmed and mempool Transactions.
Sequence
Bitcoin transaction input sequence number.
SubmitPackageResult
The global result of a Transaction package submission.
Transaction
Bitcoin transaction.
TxIn
Bitcoin transaction input.
TxOut
Bitcoin transaction output.
TxResult
A per-transaction result of a Transaction package submission.
TxStatus
The confirmation status of a Transaction.
Txid
A bitcoin transaction hash/transaction ID.
Utxo
An unspent TxOut, including its outpoint, confirmation status and value.
UtxoStatus
The confirmation status of a TxOut.
Vin
An input to a Transaction.
Vout
An output from a Transaction.
Weight
Represents block weight - the weight of a transaction or block.
Witness
The Witness is the data used to unlock bitcoin since the segwit upgrade.
Wtxid
A bitcoin witness transaction ID.

Traits

FromHex
Trait for objects that can be deserialized from hex strings.

Functions

deserialize
Deserializes an object from a vector, will error if said deserialization doesn’t consume the entire vector.
serialize
Encodes an object into a vector.

Type Aliases

ScriptHashTxsSummary
A summary of Transactions for a particular scripthash.