BlockInfo

Struct BlockInfo 

pub struct BlockInfo {
Show 13 fields pub id: BlockHash, pub height: u32, pub version: Version, pub timestamp: u64, pub tx_count: u64, pub size: usize, pub weight: Weight, pub merkle_root: TxMerkleNode, pub previousblockhash: Option<BlockHash>, pub mediantime: u64, pub nonce: u32, pub bits: CompactTarget, pub difficulty: f64,
}
A summary of a Block.

Contains additional metadata about a Block, but not the whole Block.

For the complete Block contents, use the get_block_by_hash client method.

Fields

id: BlockHash

The BlockHash of this Block.

height: u32

The block height of this Block.

version: Version

The version of this Block.

timestamp: u64

The UNIX timestamp of this Block, as claimed by the miner.

tx_count: u64

The Transaction count for this Block.

size: usize

The size of this Block, in bytes.

weight: Weight

The Weight of this Block.

merkle_root: TxMerkleNode

The Merkle root of this Block.

previousblockhash: Option<BlockHash>

The BlockHash of the previous Block.

None for the genesis block.

mediantime: u64

The Median Time Past value for this Block.

nonce: u32

This Block’s nonce.

bits: CompactTarget

The Block’s bits value, encoded as a CompactTarget.

difficulty: f64

The Block’s difficulty target value.