Struct esplora_client::api::BlockSummary
source · pub struct BlockSummary {
pub id: BlockHash,
pub time: BlockTime,
pub previousblockhash: Option<BlockHash>,
pub merkle_root: TxMerkleNode,
}Fields
id: BlockHashtime: BlockTimepreviousblockhash: Option<BlockHash>Hash of the previous block, will be None for the genesis block.
merkle_root: TxMerkleNodeTrait Implementations
sourceimpl Clone for BlockSummary
impl Clone for BlockSummary
sourcefn clone(&self) -> BlockSummary
fn clone(&self) -> BlockSummary
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for BlockSummary
impl Debug for BlockSummary
sourceimpl<'de> Deserialize<'de> for BlockSummary
impl<'de> Deserialize<'de> for BlockSummary
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl PartialEq<BlockSummary> for BlockSummary
impl PartialEq<BlockSummary> for BlockSummary
sourcefn eq(&self, other: &BlockSummary) -> bool
fn eq(&self, other: &BlockSummary) -> bool
This method tests for
self and other values to be equal, and is used
by ==.