pub struct MempoolFeesSubmitPackage {
pub base: Amount,
pub effective_feerate: Option<FeeRate>,
pub effective_includes: Option<Vec<Wtxid>>,
}Expand description
The fees for a Transaction submitted as part of a package.
Fields
base: AmountThe base fee paid by the Transaction.
effective_feerate: Option<FeeRate>The effective feerate paid by this Transaction.
Is None if the transaction was already in the mempool.
effective_includes: Option<Vec<Wtxid>>If Self::effective_feerate is provided, holds the
Wtxids of the transactions whose fees and virtual
sizes are included in effective-feerate.