pub struct MempoolStats {
pub count: usize,
pub vsize: usize,
pub total_fee: Amount,
pub fee_histogram: Vec<(FeeRate, Weight)>,
}Expand description
Statistics about the mempool.
Fields
count: usizeThe number of Transactions currently in the mempool.
vsize: usizeThe total size of mempool Transactions, in virtual bytes.
total_fee: AmountThe total fee paid by mempool Transactions.
fee_histogram: Vec<(FeeRate, Weight)>The mempool’s fee rate distribution histogram.
An array of (feerate, vsize) tuples, where each entry’s
vsize is the total vsize of Transactions paying more
than feerate but less than the previous entry’s feerate
(except for the first entry, which has no upper bound).
The Esplora API reports vsize in virtual bytes. This field
currently stores that raw value in Weight.