pub struct TxStatus {
pub confirmed: bool,
pub block_height: Option<u32>,
pub block_hash: Option<BlockHash>,
pub block_time: Option<u64>,
}Expand description
The confirmation status of a Transaction.
Fields
confirmed: boolWhether the Transaction is confirmed or not.
block_height: Option<u32>The block height that confirmed the Transaction.
block_hash: Option<BlockHash>The BlockHash of the block that confirmed the Transaction.
None if the Transaction was confirmed by the genesis block.
block_time: Option<u64>The UNIX timestamp of the block that confirmed the Transaction, as claimed by the
miner.