pub struct Vin {
pub txid: Txid,
pub vout: u32,
pub prevout: Option<Vout>,
pub scriptsig: ScriptBuf,
pub witness: Witness,
pub sequence: Sequence,
pub is_coinbase: bool,
}Expand description
An input to a Transaction.
Fields
txid: TxidThe Txid of the Transaction that created this output.
vout: u32The index of this output in the Transaction that created it.
prevout: Option<Vout>This input’s previous output Amount and script pubkey.
None if this input spends a coinbase output.
scriptsig: ScriptBufThe Script that unlocks this input.
witness: WitnessThe Witness that unlocks this input.
sequence: SequenceThe sequence value for this input.
is_coinbase: boolWhether this is a coinbase input.