pub struct MempoolStats {
pub count: usize,
pub vsize: usize,
pub total_fee: u64,
pub fee_histogram: Vec<(f64, usize)>,
}Expand description
Statistics about the mempool.
Fields
count: usizeThe number of Transactions in the mempool.
vsize: usizeThe total size of mempool Transactions, in virtual bytes.
total_fee: u64The total fee paid by mempool Transactions, in satoshis.
fee_histogram: Vec<(f64, usize)>The mempool’s fee rate distribution histogram.
An array of (feerate, vsize) tuples, where each entry’s vsize is the total vsize
of Transactions paying more than feerate but less than the previous entry’s feerate
(except for the first entry, which has no upper bound).